@@ -116,7 +116,7 @@ public class JoinCommand implements GroupCommand {
 
     void doWelcome(Stanza stanza, GroupDispatcher groupDispatcher) throws OXException {
         groupDispatcher.join(stanza.getOnBehalfOf(), stanza.getSelector(), stanza);
-        Stanza welcomeMessage = groupDispatcher.getWelcomeMessage(stanza.getOnBehalfOf());
+        Stanza welcomeMessage = groupDispatcher.getWelcomeMessage(stanza.getOnBehalfOf(), stanza);
         if (null == welcomeMessage) {
             IllegalStateException x = new IllegalStateException("There is no welcome message for " + stanza.getOnBehalfOf());
             throw RealtimeExceptionCodes.JOIN_FAILED.create(x, stanza.getFrom().toString());
