@@ -58,6 +58,7 @@ import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.Callable;
+import org.osgi.framework.BundleContext;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.hazelcast.nio.serialization.Portable;
@@ -76,6 +77,9 @@ import com.openexchange.realtime.hazelcast.serialization.util.PortableIDToOXExce
 import com.openexchange.realtime.packet.ID;
 import com.openexchange.realtime.packet.Stanza;
 import com.openexchange.realtime.util.IDMap;
+import com.openexchange.serialization.BundleClassResolver;
+import com.openexchange.serialization.ClassResolver;
+import com.openexchange.serialization.FilteringObjectStreamFactory;
 
 /**
  * {@link PortableStanzaDispatcher}
@@ -184,7 +188,7 @@ public class PortableStanzaDispatcher implements Callable<IDMap<OXException>>, C
         byte[] stanzaBytes = reader.readByteArray(FIELD_STANZA);
         try {
             stanza = getStanza(stanzaBytes);
-        } catch (ClassNotFoundException e) {
+        } catch (ClassNotFoundException | OXException e) {
             throw new IOException(e);
         }
     }
@@ -217,15 +221,19 @@ public class PortableStanzaDispatcher implements Callable<IDMap<OXException>>, C
      * imports.
      *
      * @param stanzaBytes The byte array representation of the Stanza
-     * @return The deserialzed {@link Stanza}
+     * @return The deserialized {@link Stanza}
      * @throws IOException If reading the byte array fails
      * @throws ClassNotFoundException If the OSGI imports are too restrictive and not all classes that make up a {@link Stanza} subclass are
      *             accessible
+     * @throws OXException
      */
-    private static Stanza getStanza(byte[] stanzaBytes) throws IOException, ClassNotFoundException {
-        final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(stanzaBytes);
-        final ObjectInputStream objectInputStream = new ObjectInputStream(byteArrayInputStream);
-        return Stanza.class.cast(objectInputStream.readObject());
+    private Stanza getStanza(byte[] stanzaBytes) throws IOException, ClassNotFoundException, OXException {
+        BundleContext bundleContext = Services.getBundleContext();
+        ClassResolver bundleClassResolver = bundleContext == null ? null : new BundleClassResolver(bundleContext);
+        ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(stanzaBytes);
+        try (ObjectInputStream objectInputStream = Services.getService(FilteringObjectStreamFactory.class).createFilteringStream(byteArrayInputStream, this, bundleClassResolver)) {
+            return Stanza.class.cast(objectInputStream.readObject());
+        }
     }
 
 }
