@@ -50,7 +50,6 @@
 package com.openexchange.realtime.hazelcast.osgi;
 
 import static com.openexchange.realtime.hazelcast.channel.HazelcastAccess.discoverMapName;
-import java.util.concurrent.atomic.AtomicBoolean;
 import org.osgi.framework.BundleException;
 import org.osgi.framework.ServiceReference;
 import com.hazelcast.config.Config;
@@ -88,11 +87,10 @@ import com.openexchange.timer.TimerService;
  */
 public class HazelcastRealtimeActivator extends HousekeepingActivator {
 
-    private static org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(HazelcastRealtimeActivator.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(HazelcastRealtimeActivator.class);
 
-    private final AtomicBoolean isStopped = new AtomicBoolean(true);
-    private volatile HazelcastResourceDirectory directory;
-    private volatile String cleanerRegistrationId;
+    private HazelcastResourceDirectory directory;
+    private String cleanerRegistrationId;
 
     @Override
     protected Class<?>[] getNeededServices() {
@@ -108,7 +106,7 @@ public class HazelcastRealtimeActivator extends HousekeepingActivator {
     }
 
     @Override
-    protected void startBundle() throws Exception {
+    protected synchronized void startBundle() throws Exception {
         LOG.info("Starting bundle: {}", getClass().getCanonicalName());
         Services.setServiceLookup(this);
 
@@ -176,12 +174,12 @@ public class HazelcastRealtimeActivator extends HousekeepingActivator {
             LOG.error("Failed to expose ManagementObjects", oxe);
         }
         openTrackers();
-        isStopped.set(false);
+        Services.getStoppedFlag().set(false);
     }
 
     @Override
-    protected void stopBundle() throws Exception {
-        if (isStopped.compareAndSet(false, true)) {
+    protected synchronized void stopBundle() throws Exception {
+        if (Services.getStoppedFlag().compareAndSet(false, true)) {
             LOG.info("Stopping bundle: {}", getClass().getCanonicalName());
 
             HazelcastResourceDirectory directory = this.directory;
