@@ -49,6 +49,7 @@
 
 package com.openexchange.realtime.hazelcast.osgi;
 
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 import com.openexchange.server.ServiceLookup;
 
@@ -67,6 +68,17 @@ public final class Services {
         super();
     }
 
+    private static final AtomicBoolean STOPPED = new AtomicBoolean(true);
+
+    /**
+     * Gets the stopped flag
+     *
+     * @return The stopped flag
+     */
+    public static AtomicBoolean getStoppedFlag() {
+        return STOPPED;
+    }
+
     private static final AtomicReference<ServiceLookup> REF = new AtomicReference<ServiceLookup>();
 
     /**
