@@ -103,7 +103,7 @@ public class RealtimeActivator extends HousekeepingActivator {
 
     private final AtomicBoolean isStopped = new AtomicBoolean(true);
 
-    private volatile SyntheticChannel synth;
+    private SyntheticChannel synth;
     private RealtimeConfig realtimeConfig;
 
     /**
@@ -119,7 +119,7 @@ public class RealtimeActivator extends HousekeepingActivator {
     }
 
     @Override
-    protected void startBundle() throws Exception {
+    protected synchronized void startBundle() throws Exception {
         RealtimeServiceRegistry.SERVICES.set(this);
         ManagementHouseKeeper managementHouseKeeper = ManagementHouseKeeper.getInstance();
         managementHouseKeeper.initialize(this);
@@ -173,8 +173,8 @@ public class RealtimeActivator extends HousekeepingActivator {
         });
 
         DefaultPayloadTreeConverter converter = new DefaultPayloadTreeConverter(this);
-        PayloadTree.CONVERTER = converter;
-        PayloadTreeNode.CONVERTER = converter;
+        PayloadTree.setConverter(converter);
+        PayloadTreeNode.setConverter(converter);
 
         registerService(PayloadTreeConverter.class, converter);
 
@@ -202,7 +202,7 @@ public class RealtimeActivator extends HousekeepingActivator {
     }
 
     @Override
-    protected void stopBundle() throws Exception {
+    protected synchronized void stopBundle() throws Exception {
         if (isStopped.compareAndSet(false, true)) {
             synth.shutdown();
             // Conceal all ManagementObjects for this bundle and remove them from the housekeeper
@@ -210,6 +210,8 @@ public class RealtimeActivator extends HousekeepingActivator {
             ID.ID_MANAGER_REF.set(null);
             RealtimeJanitors.getInstance().cleanup();
             realtimeConfig.stop();
+            PayloadTree.setConverter(null);
+            PayloadTreeNode.setConverter(null);
             super.stopBundle();
         }
     }
